# Table of Contents

- [custom-fact-sheet-types](<./custom-fact-sheet-types.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Custom Fact Sheet Types](<./Custom-Fact-Sheet-Types.md>)
  - [Overview](<./Custom-Fact-Sheet-Types/Overview.md>)
  - [Best Practices](<./Custom-Fact-Sheet-Types/Best-Practices.md>)
  - [Creating a Custom Fact Sheet Type](<./Custom-Fact-Sheet-Types/Creating-a-Custom-Fact-Sheet-Type.md>)
  - [Deleting a Custom Fact Sheet Type](<./Custom-Fact-Sheet-Types/Deleting-a-Custom-Fact-Sheet-Type.md>)
  - [Was this page helpful?](<./Custom-Fact-Sheet-Types/Was-this-page-helpful.md>)
